@@ -44,21 +44,32 @@
 		stop('points should be vectors of length 2, matrices with 2 columns, or a SpatialPoints* object')
 	}
 
+	if (! is.numeric(p) ) { p[] <- as.numeric(p) }
+	
 	if (checkLonLat) {
-		if (min(p[,1], na.rm=TRUE) < -720) { stop('longitude < -720') }
-		if (max(p[,1], na.rm=TRUE) > 720) {  stop('longitude > 720')  }
-		if (min(p[,1], na.rm=TRUE) < -360) { warning('longitude < -360') }
-		if (max(p[,1], na.rm=TRUE) > 360) {  warning('longitude > 360')  }
-		if (min(p[,2], na.rm=TRUE) < -90) {  stop('latitude < -90')  }
-		if (max(p[,2], na.rm=TRUE) > 90) {  stop('latitude > 90')  }
+		if (length(na.omit(p[,1])) > 0) {
+			if (min(p[,1], na.rm=TRUE) < -720) { stop('longitude < -720') }
+			if (max(p[,1], na.rm=TRUE) > 720) {  stop('longitude > 720')  }
+			if (min(p[,1], na.rm=TRUE) < -360) { warning('longitude < -360') }
+		}
+		if (length(na.omit(p[,2])) > 0) {
+			if (max(p[,1], na.rm=TRUE) > 360) {  warning('longitude > 360')  }
+			if (min(p[,2], na.rm=TRUE) < -90) {  stop('latitude < -90')  }
+			if (max(p[,2], na.rm=TRUE) > 90) {  stop('latitude > 90')  }
+		}
 	}
 	
-	if (! is.numeric(p) ) { p[] <- as.numeric(p) }
 	
 	if (poly) {
 		if (! isTRUE(all.equal(p[1,], p[nrow(p),]))) {
 			p <- rbind(p, p[1,])
 		} 
+
+		i <- which(p[-nrow(p),] == p[-1,])
+		if (length(i) > 0) {
+			p <- p[-i, ,drop=FALSE]
+		}
+	
 		.isPolygon(p)
 	}
 	
